
#ifndef _C10_re494_
#define _C10_re494_

#ifdef __cplusplus
extern "C" {
#endif

extern void F559_7711(EIF_REFERENCE, EIF_REFERENCE);
extern void F559_7720(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit494(void);

#ifdef __cplusplus
}
#endif

#endif
